4.38. umbra.reporter — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.38. umbra.reporter

reporter.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Reporter` class and various others exceptions handling related objects.

Others:

## 4.38.1. Module Attributes

`umbra.reporter.` `LOGGER`

`umbra.reporter.` `UI_FILE`

## 4.38.2. Functions

`umbra.reporter.` `baseExceptionHandler`(*args)

  This definition provides a base exception handler.

  Parameters: | *args – Arguments. ( * )
  Returns: | Definition success. ( Boolean )

`umbra.reporter.` `systemExitExceptionHandler`(*args)

  This definition provides a system exit exception handler.

  Parameters: | *args – Arguments. ( * )
  Returns: | Definition success. ( Boolean )

`umbra.reporter.` `criticalExceptionHandler`(object)

  This decorator is used to mark an object that would system exit in case of critical exception.

  Parameters: | object – Object to decorate. ( Object )
  Returns: | Object. ( Object )

`umbra.reporter.` `installExceptionReporter`(report=True)

  This definition installs the exceptions reporter.

  Parameters: | report – Report to Crittercism. ( Boolean )
  Returns: | Reporter instance. ( Reporter )

`umbra.reporter.` `uninstallExceptionReporter`()

  This definition uninstalls the exceptions reporter.

  Returns: | Definition success. ( Boolean )

`umbra.reporter.` `enableExceptionReporter`()

  This definition enables the exceptions reporter.

  Returns: | Definition success. ( Boolean )

`umbra.reporter.` `disableExceptionReporter`()

  This definition disables the exceptions reporter.

  Returns: | Definition success. ( Boolean )

## 4.38.3. Classes

class `umbra.reporter.` `Reporter`(parent=None, report=True, enabled=True, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  This class provides an exception reporting Widget.

  Parameters: | parent – Object parent. ( QObject ) report – Report to Crittercism. ( Boolean ) enabled – Is reporter enabled. ( Boolean ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `report`

    This method is the property for self.__report attribute.

    Returns: | self.__report. ( Boolean )

  `enabled`

    This method is the property for self.__enabled attribute.

    Returns: | self.__enabled. ( Boolean )

  `show`()

    This method reimplements the `QWidget.show()` method.

  `handleException`(*args)

    This method handles given exception.

    Parameters: | *args – Arguments. ( * )

  static `formatHtmlException`(*args)

    This method formats given exception as an html text.

    Parameters: | *args – Arguments. ( * )
    Returns: | Exception html text. ( String )

  static `formatTextException`(*args)

    This method formats given exception as a text.

    Parameters: | *args – Arguments. ( * )
    Returns: | Exception text. ( String )

  `reportExceptionToCrittercism`(*args)

    This method reports given exception to Crittercism.

    Parameters: | *args – Arguments. ( * )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »